.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   session factory
      A callable, which, when called with a single argument named
      ``request``, returns a session object.

   Beaker
      A `sessioning and caching package <http://beaker.groovie.org/>`_
      by Ben Bangert.

   Pyramid
      A `web framework <http://pylonshq.com/pyramid>`_.
